@@ -1,9 +1,9 @@
 import logging
 
 import dash
-import dash_core_components as dcc
+from dash import dcc
 import dash_bootstrap_components as dbc
-import dash_html_components as html
+from dash import html
 import logzero
 from sqlalchemy.orm import Session
 from dash.dependencies import Input, Output
