@@ -1,6 +1,6 @@
-import dash_core_components as dcc
+from dash import dcc
 import dash_bootstrap_components as dbc
-import dash_html_components as html
+from dash import html
 from dash.dependencies import Output, Input, State
 from sqlalchemy.orm import Session
 from covigator.dashboard.figures.lineages import LineageFigures
@@ -35,6 +35,7 @@ def get_lineages_tab_graphs():
         children=[
             html.Br(),
             html.Div(id=ID_LINEAGES_GRAPH),
+            html.Hr(),
             html.Br(),
             html.Div(id=ID_LINEAGES_TABLE),
         ])
