@@ -1,6 +1,6 @@
-import dash_core_components as dcc
+from dash import dcc
 import dash_bootstrap_components as dbc
-import dash_html_components as html
+from dash import html
 from dash.dependencies import Output, Input, State
 from sqlalchemy.orm import Session
 
