@@ -1,6 +1,6 @@
-import dash_core_components as dcc
+from dash import dcc
 import dash_bootstrap_components as dbc
-import dash_html_components as html
+from dash import html
 from dash.dependencies import Output, Input, State
 from sqlalchemy.orm import Session
 from covigator.dashboard.figures.samples import SampleFigures
@@ -36,6 +36,7 @@ def get_samples_tab_graphs():
         children=[
             html.Br(),
             html.Div(id=ID_ACCUMULATED_SAMPLES_GRAPH),
+            html.Hr(),
             html.Br(),
             html.Div(id=ID_DN_DS_GRAPH),
         ])
