@@ -334,34 +334,6 @@ class Queries:
         subquery = query.group_by(klass.position, klass.annotation_highest_impact, klass.hgvs_p).subquery()
         return pd.read_sql(
             self.session.query(subquery).filter(subquery.c.count_occurrences > 1).statement, self.session.bind)
-
-    def get_variant_ids_by_sample(self, sample_id, source: str, maximum_length: int) -> List[str]:
-        klass = self.get_variant_observation_klass(source=source)
-        return self.session.query(klass.variant_id) \
-            .filter(and_(klass.sample == sample_id, klass.length < maximum_length, klass.length > -maximum_length)) \
-            .order_by(klass.position, klass.reference, klass.alternate) \
-            .all()
-
-    def increment_variant_cooccurrence(
-            self, variant_id_one: str, variant_id_two: str, source: str):
-
-        klazz = self.get_variant_cooccurrence_klass(source=source)
-        variant_cooccurrence = self.session.query(klazz) \
-            .filter(and_(klazz.variant_id_one == variant_id_one,
-                         klazz.variant_id_two == variant_id_two)) \
-            .first()
-        if variant_cooccurrence is None:
-            variant_cooccurrence = klazz(
-                variant_id_one=variant_id_one,
-                variant_id_two=variant_id_two,
-                count=1)
-            self.session.add(variant_cooccurrence)
-        else:
-            # NOTE: it is important to increase the counter like this to avoid race conditions
-            # the increase happens in the database server and not in python
-            # see https://stackoverflow.com/questions/2334824/how-to-increase-a-counter-in-sqlalchemy
-            variant_cooccurrence.count = klazz.count + 1
-        self.session.commit()
     
     def count_samples(self, source: str, cache=True) -> int:
         self._assert_data_source(source)
@@ -519,15 +491,16 @@ class Queries:
         counts['month'] = pd.to_datetime(counts['month'], utc=True)
         return counts
 
-    def get_sparse_cooccurrence_matrix(self, gene_name, domain, min_cooccurrence=5) -> pd.DataFrame:
+    def get_sparse_cooccurrence_matrix(self, gene_name, domain, source: str, min_cooccurrence=5) -> pd.DataFrame:
         """
         Returns the sparse cooccurrence matrix of all non synonymous variants in a gene or domain with at least
         min_occurrences occurrences.
         """
         # query for cooccurrence matrix
+        variant_cooccurrence_klass = self.get_variant_cooccurrence_klass(source=source)
         variant_one = aliased(Variant)
         variant_two = aliased(Variant)
-        query = self.session.query(VariantCooccurrence,
+        query = self.session.query(variant_cooccurrence_klass,
                                    variant_one.position,
                                    variant_one.reference,
                                    variant_one.alternate,
@@ -536,26 +509,18 @@ class Queries:
                                    variant_two.hgvs_p.label("hgvs_p_two"),
                                    (variant_one.hgvs_p + " - " + variant_two.hgvs_p).label("hgvs_tooltip"))
 
-        query = query.filter(VariantCooccurrence.count >= min_cooccurrence) \
-            .join(variant_one, and_(VariantCooccurrence.variant_id_one == variant_one.variant_id)) \
-            .join(variant_two, and_(VariantCooccurrence.variant_id_two == variant_two.variant_id))
+        query = query.filter(variant_cooccurrence_klass.count >= min_cooccurrence) \
+            .join(variant_one, and_(variant_cooccurrence_klass.variant_id_one == variant_one.variant_id)) \
+            .join(variant_two, and_(variant_cooccurrence_klass.variant_id_two == variant_two.variant_id))
 
         if domain is not None:
             query = query.filter(and_(
                 variant_one.pfam_name == domain,
-                variant_one.annotation != SYNONYMOUS_VARIANT,
-                variant_two.pfam_name == domain,
-                variant_two.annotation != SYNONYMOUS_VARIANT))
+                variant_two.pfam_name == domain))
         elif gene_name is not None:
             query = query.filter(and_(
                 variant_one.gene_name == gene_name,
-                variant_one.annotation != SYNONYMOUS_VARIANT,
-                variant_two.gene_name == gene_name,
-                variant_two.annotation != SYNONYMOUS_VARIANT))
-        else:
-            query = query.filter(and_(
-                variant_one.annotation != SYNONYMOUS_VARIANT,
-                variant_two.annotation != SYNONYMOUS_VARIANT))
+                variant_two.gene_name == gene_name))
 
         self._print_query(query=query)
         data = pd.read_sql(query.statement, self.session.bind)
